schemetools.SchemePair
======================

.. abjad-lineage:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair

.. autoclass:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.force_quotes
   :noindex:

.. autoattribute:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__eq__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__ge__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__gt__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__le__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__lt__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__ne__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__repr__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.SchemePair.__str__
   :noindex:
